power_cogs.config package — power_cogs 0.1.0 documentation

# power_cogs.config package

## Subpackages

- power_cogs.config.base package
  - Submodules
  - power_cogs.config.base.base_config module
  - Module contents
- power_cogs.config.torch package
  - Submodules
  - power_cogs.config.torch.torch_config module
  - Module contents
- power_cogs.config.tune package
  - Submodules
  - power_cogs.config.tune.tune_config module
  - Module contents

## Submodules

## power_cogs.config.config module

Import your main config files here:

## power_cogs.config.config_utils module

`power_cogs.config.config_utils.` `add_config`(config_dict: Dict[str, Any]) → None

`power_cogs.config.config_utils.` `add_configs`(list_of_config_dicts: List[Dict[str, Any]]) → None

`power_cogs.config.config_utils.` `clear_configs`()

`power_cogs.config.config_utils.` `setup_config`()

`power_cogs.config.config_utils.` `verify_config_dict`(config) → None

## power_cogs.config.load_config module

## power_cogs.config.mnist_config module

class `power_cogs.config.mnist_config.` `MNISTConfig`(defaults: List[Any] = <factory>, trainer: Any = '???')

  Bases: `object`

  `trainer` = '???'

class `power_cogs.config.mnist_config.` `MNISTDatasetConfig`(_target_: str = 'power_cogs.dataset.mnist_dataset.MNISTDataset')

  Bases: `power_cogs.config.base.base_config.BaseDatasetConfig`

class `power_cogs.config.mnist_config.` `MNISTModelConfig`(_target_: str = 'power_cogs.model.mnist_model.MNISTModel', input_dims: Union[int, NoneType] = None, hidden_dims: List[int] = <factory>, output_dims: Union[int, NoneType] = None, output_activation: str = 'torch.nn.functional.relu', use_normal_init: bool = True, normal_std: float = 0.01, zero_bias: bool = False)

  Bases: `power_cogs.config.base.base_config.BaseModelConfig`

  `input_dims` = None
  `normal_std` = 0.01
  `output_activation` = 'torch.nn.functional.relu'
  `output_dims` = None
  `use_normal_init` = True
  `zero_bias` = False

class `power_cogs.config.mnist_config.` `MNISTTrainerConfig`(defaults: List[Any] = <factory>, _target_: str = 'power_cogs.trainer.mnist_trainer.MNISTTrainer', name: 'Optional[str]' = None, pretrained_path: 'Optional[str]' = None, visualize_output: 'bool' = True, use_cuda: 'bool' = False, device_id: 'int' = 0, early_stoppage: 'bool' = False, loss_threshold: 'float' = -inf, batch_size: 'int' = 32, epochs: 'int' = 100, checkpoint_interval: 'int' = 100, num_samples: 'Optional[int]' = None, model_config: 'Any' = '???', dataset_config: 'Any' = '???', optimizer_config: 'Any' = '???', scheduler_config: 'Any' = '???', logging_config: 'Any' = '???', dataloader_config: 'Any' = '???', tune_config: 'Any' = '???', config: 'Any' = <factory>)

  Bases: `power_cogs.config.base.base_config.BaseTrainerConfig`

## Module contents

`power_cogs.config.` `clear_configs`()

`power_cogs.config.` `add_config`(config_dict: Dict[str, Any]) → None

`power_cogs.config.` `add_configs`(list_of_config_dicts: List[Dict[str, Any]]) → None

`power_cogs.config.` `setup_config`()

`power_cogs.config.` `load_config`(config_path: Optional[str] = None) → Any